// Copyright (C) 1999-2000 Id Software, Inc.
//
#include "g_local.h"


/*
=======================================================================

  SESSION DATA

Session data is the only data that stays persistant across level loads
and tournament restarts.
=======================================================================
*/

extern int	borgQueenClientNum;
extern int	noJoinLimit;
extern int	numKilled;

/*
================
G_WriteClientSessionData

Called on game shutdown
================
*/
void G_WriteClientSessionData( gclient_t *client ) {
	const char	*s;
	const char	*var;

	s = va("%i %i %i %i %i %i %i %i %i %i %i %i %i %i %i %i %i %i %i %i %i %i %i %i", 
		client->sess.sessionTeam,
		client->sess.sessionClass,
		client->sess.spectatorTime,
		client->sess.spectatorState,
		client->sess.spectatorClient,
		client->sess.score,
		client->sess.imod,
		client->sess.scav,
		client->sess.stas,
		client->sess.gren,
		client->sess.tetr,
		client->sess.phot,
		client->sess.weld,
		client->sess.armor,
		client->sess.wins,
		client->sess.a,
		client->sess.b,
		client->sess.c,
		client->sess.d,
		client->sess.e,
		client->sess.f,
		client->sess.g,
		client->sess.h,
		client->sess.losses
		);

	var = va( "session%i", client - level.clients );

	trap_Cvar_Set( var, s );
}

/*
================
G_ReadSessionData

Called on a reconnect
================
*/
void G_ReadSessionData( gclient_t *client ) {
	char	s[MAX_STRING_CHARS];
	const char	*var;

	var = va( "session%i", client - level.clients );
	trap_Cvar_VariableStringBuffer( var, s, sizeof(s) );

	sscanf( s, "%i %i %i %i %i %i %i %i %i %i %i %i %i %i %i %i %i %i %i %i %i %i %i %i", 
		&client->sess.sessionTeam,
		&client->sess.sessionClass,
		&client->sess.spectatorTime,
		&client->sess.spectatorState,
		&client->sess.spectatorClient,
		&client->sess.score,
		&client->sess.imod,
		&client->sess.scav,
		&client->sess.stas,
		&client->sess.gren,
		&client->sess.tetr,
		&client->sess.phot,
		&client->sess.weld,
		&client->sess.armor,
		&client->sess.wins,
		&client->sess.a,
		&client->sess.b,
		&client->sess.c,
		&client->sess.d,
		&client->sess.e,
		&client->sess.f,
		&client->sess.g,
		&client->sess.h,
		&client->sess.losses
		);
	client->ps.persistant[PERS_SCORE] = client->sess.score;
}


/*
================
G_InitSessionData

Called on a first-time connect
================
*/
void G_InitSessionData( gclient_t *client, char *userinfo ) {
	clientSession_t	*sess;

	sess = &client->sess;


	sess->sessionTeam = TEAM_SPECTATOR;	
	

	client->ps.persistant[PERS_SCORE] = client->sess.score;

	sess->sessionClass = PC_NOCLASS;
	sess->spectatorState = SPECTATOR_FREE;
	sess->spectatorTime = level.time;

	G_WriteClientSessionData( client );
}


/*
==================
G_InitWorldSession

==================
*/
void G_InitWorldSession( void ) {
	char	s[MAX_STRING_CHARS];
	int			gt;

	trap_Cvar_VariableStringBuffer( "session", s, sizeof(s) );
	gt = atoi( s );
	
	// if the gametype changed since the last session, don't use any
	// client sessions
	if ( g_gametype.integer != gt ) {
		level.newSession = qtrue;
		G_Printf( "Gametype changed, clearing session data.\n" );
	}
}

/*
==================
G_WriteSessionData

==================
*/
void G_WriteSessionData( void ) {
	int		i;

	trap_Cvar_Set( "session", va("%i", g_gametype.integer) );

	for ( i = 0 ; i < level.maxclients ; i++ ) {
		if ( level.clients[i].pers.connected == CON_CONNECTED ) {
			G_WriteClientSessionData( &level.clients[i] );
		}
	}
}
