// Copyright (C) 1999-2000 Id Software, Inc.
//
/*
=======================================================================

INGAME MENU

=======================================================================
*/


#include "ui_local.h"

void UI_SetupWeaponsMenu( void );

int		ingameFlag = qfalse;	// true when in game menu is in use

#define INGAME_MENU_VERTICAL_SPACING	28

#define ID_TEAM					10
#define ID_ADDBOTS				11
#define ID_REMOVEBOTS			12
#define ID_SETUP				13
#define ID_SERVERINFO			14
#define ID_LEAVEARENA			15
#define ID_RESTART				16
#define ID_QUIT					17
#define ID_RESUME				18
#define ID_TEAMORDERS			19
#define ID_BUYMENU				20
#define ID_SCREENSHOT			21
#define ID_INGAMEMENU			125
#define ID_INGAME_QUIT_YES		131
#define ID_INGAME_QUIT_NO		132

typedef struct 
{
	menuframework_s	menu;

	menubitmap_s	team;
	menubitmap_s	setup;
	menubitmap_s	server;
	menubitmap_s	leave;
	menubitmap_s	restart;
	menubitmap_s	addbots;
	menubitmap_s	removebots;
	menubitmap_s	teamorders;
	menubitmap_s	buymenu;
	menubitmap_s	screenshot;
	menubitmap_s	resume;
} ingamemenu_t;

static ingamemenu_t	s_ingame;

static int ingame_buttons[10][2] =
{
{152,220},
{152,220 + INGAME_MENU_VERTICAL_SPACING},
{152,220 + (INGAME_MENU_VERTICAL_SPACING *2)},
{152,220 + (INGAME_MENU_VERTICAL_SPACING *3)},
{152,220 + (INGAME_MENU_VERTICAL_SPACING *4)},

{368,220},
{368,220 + INGAME_MENU_VERTICAL_SPACING},
{368,220 + (INGAME_MENU_VERTICAL_SPACING *2)},
{368,220 + (INGAME_MENU_VERTICAL_SPACING *3)},
{368,220 + (INGAME_MENU_VERTICAL_SPACING *4)},
};


typedef struct 
{
	menuframework_s	menu;

	menubitmap_s	ingamemenu;
	menubitmap_s	no;
	menubitmap_s	yes;
} ingamequitmenu_t;

static ingamequitmenu_t	s_ingamequit;

/*
=================
InGame_RestartAction
=================
*/
static void InGame_RestartAction( qboolean result ) 
{
	if( !result ) 
	{
		return;
	}

	UI_PopMenu();
	trap_Cmd_ExecuteText( EXEC_APPEND, "map_restart 0\n" );
}


/*
=================
InGame_LeaveAction
=================
*/
static void InGame_LeaveAction( qboolean result ) 
{
	if( !result ) 
	{
		return;
	}

	UI_PopMenu();
	trap_Cmd_ExecuteText( EXEC_APPEND, "disconnect\n" );
}


/*
=================
InGame_Event
=================
*/
void InGame_Event( void *ptr, int notification ) 
{
	if( notification != QM_ACTIVATED ) 
	{
		return;
	}

	switch( ((menucommon_s*)ptr)->id ) 
	{
	case ID_TEAM:
		UI_TeamMainMenu();
		break;

	case ID_SETUP:
		UI_SetupWeaponsMenu();
		break;

	case ID_SCREENSHOT:
		UI_ForceMenuOff();
		trap_Cmd_ExecuteText( EXEC_APPEND, "wait; wait; wait; wait; screenshot\n" );
		break;

	case ID_LEAVEARENA:
		UI_ConfirmMenu( menu_normal_text[MNT_LEAVE_MATCH], 0, InGame_LeaveAction );
//		trap_Cmd_ExecuteText( EXEC_APPEND, "disconnect\n" );
		break;

	case ID_RESTART:
		UI_ConfirmMenu( menu_normal_text[MNT_RESTART_MATCH], 0, InGame_RestartAction );
		break;

	case ID_QUIT:
		UI_QuitMenu();
//		UI_ConfirmMenu( "EXIT GAME?", NULL, InGame_QuitAction );
		break;

	case ID_SERVERINFO:
		UI_ServerInfoMenu();
		break;

	case ID_ADDBOTS:
		UI_AddBotsMenu();
		break;

	case ID_REMOVEBOTS:
		UI_RemoveBotsMenu();
		break;

	case ID_TEAMORDERS:
		UI_TeamOrdersMenu(0);
		break;
	case ID_BUYMENU:
		UI_DynamicMenu();
		break;

	case ID_RESUME:
		UI_PopMenu();
		break;
	}
}

/*
=================
UI_InGameMenu_Draw
=================
*/
static void UI_InGameMenu_Draw( void ) 
{

	UI_MenuFrame(&s_ingame.menu);

	// Rounded button that takes place of INGAME MENU button
	trap_R_SetColor( colorTable[CT_LTBROWN1]);
	UI_DrawHandlePic( 482, 136,  MENU_BUTTON_MED_WIDTH - 22, MENU_BUTTON_MED_HEIGHT, uis.whiteShader);
	UI_DrawHandlePic( 460 + MENU_BUTTON_MED_WIDTH - 6, 136,  -19,  MENU_BUTTON_MED_HEIGHT, uis.graphicButtonLeftEnd);	//right

	trap_R_SetColor( colorTable[CT_LTBROWN1]);
	UI_DrawHandlePic(30,203,  47, 186, uis.whiteShader);	// Long left column square on bottom 3rd

	// Left rounded ends for buttons
	trap_R_SetColor( colorTable[CT_DKPURPLE1]);

	UI_DrawHandlePic(s_ingame.team.generic.x - 14, s_ingame.team.generic.y, 
		MENU_BUTTON_MED_HEIGHT, MENU_BUTTON_MED_HEIGHT, uis.graphicButtonLeftEnd);

	UI_DrawHandlePic(s_ingame.addbots.generic.x - 14, s_ingame.addbots.generic.y, 
		MENU_BUTTON_MED_HEIGHT, MENU_BUTTON_MED_HEIGHT, uis.graphicButtonLeftEnd);

	UI_DrawHandlePic(s_ingame.removebots.generic.x - 14, s_ingame.removebots.generic.y, 
		MENU_BUTTON_MED_HEIGHT, MENU_BUTTON_MED_HEIGHT, uis.graphicButtonLeftEnd);

	UI_DrawHandlePic(s_ingame.teamorders.generic.x - 14, s_ingame.teamorders.generic.y, 
		MENU_BUTTON_MED_HEIGHT, MENU_BUTTON_MED_HEIGHT, uis.graphicButtonLeftEnd);

	UI_DrawHandlePic(s_ingame.buymenu.generic.x - 14, s_ingame.buymenu.generic.y, 
		MENU_BUTTON_MED_HEIGHT, MENU_BUTTON_MED_HEIGHT, uis.graphicButtonLeftEnd);

	UI_DrawHandlePic(s_ingame.setup.generic.x - 14, s_ingame.setup.generic.y, 
		MENU_BUTTON_MED_HEIGHT, MENU_BUTTON_MED_HEIGHT, uis.graphicButtonLeftEnd);

	UI_DrawHandlePic(s_ingame.server.generic.x - 14, s_ingame.server.generic.y, 
		MENU_BUTTON_MED_HEIGHT, MENU_BUTTON_MED_HEIGHT, uis.graphicButtonLeftEnd);

	UI_DrawHandlePic(s_ingame.restart.generic.x - 14, s_ingame.restart.generic.y, 
		MENU_BUTTON_MED_HEIGHT, MENU_BUTTON_MED_HEIGHT + 6, uis.graphicButtonLeftEnd);

	UI_DrawHandlePic(s_ingame.resume.generic.x - 14, s_ingame.resume.generic.y, 
		MENU_BUTTON_MED_HEIGHT, MENU_BUTTON_MED_HEIGHT + 6, uis.graphicButtonLeftEnd);

	UI_DrawHandlePic(s_ingame.leave.generic.x - 14, s_ingame.leave.generic.y, 
		MENU_BUTTON_MED_HEIGHT, MENU_BUTTON_MED_HEIGHT + 6, uis.graphicButtonLeftEnd);

	UI_DrawProportionalString(  74,  66, "15567",UI_RIGHT|UI_TINYFONT, colorTable[CT_BLACK]);
	UI_DrawProportionalString(  74,  84, "2439",UI_RIGHT|UI_TINYFONT, colorTable[CT_BLACK]);
	UI_DrawProportionalString(  74,  188, "3814",UI_RIGHT|UI_TINYFONT, colorTable[CT_BLACK]);
	UI_DrawProportionalString(  74,  206, "4800",UI_RIGHT|UI_TINYFONT, colorTable[CT_BLACK]);
	UI_DrawProportionalString(  74,  395, "5671-1",UI_RIGHT|UI_TINYFONT, colorTable[CT_BLACK]);

	UI_DrawProportionalString( 584, 142, "1219",UI_RIGHT|UI_TINYFONT, colorTable[CT_BLACK]);

	// standard menu drawing
	Menu_Draw( &s_ingame.menu );

}

/*
=================
InGame_MenuInit
=================
*/
void InGame_MenuInit( void ) 
{
	int		y,x;
	uiClientState_t	cs;
	char	info[MAX_INFO_STRING];
	int		team;

	memset( &s_ingame, 0 ,sizeof(ingamemenu_t) );

	InGame_Cache();

	s_ingame.menu.wrapAround			= qtrue;
	s_ingame.menu.fullscreen			= qtrue;
	s_ingame.menu.descX					= MENU_DESC_X;
	s_ingame.menu.descY					= MENU_DESC_Y;
	s_ingame.menu.draw					= UI_InGameMenu_Draw;
	s_ingame.menu.titleX				= MENU_TITLE_X;
	s_ingame.menu.titleY				= MENU_TITLE_Y;
	s_ingame.menu.titleI				= MNT_INGAMEMAIN_TITLE;
	s_ingame.menu.footNoteEnum			= MNT_INGAME_MENU;

	x = 305;
	y = 196;
	s_ingame.team.generic.type			= MTYPE_BITMAP;
	s_ingame.team.generic.flags			= QMF_HIGHLIGHT_IF_FOCUS;
	s_ingame.team.generic.x				= x;
	s_ingame.team.generic.y				= y;
	s_ingame.team.generic.id			= ID_TEAM;
	s_ingame.team.generic.name			= BUTTON_GRAPHIC_LONGRIGHT;
	s_ingame.team.generic.callback		= InGame_Event; 
	s_ingame.team.width					= MENU_BUTTON_MED_WIDTH;
	s_ingame.team.height				= MENU_BUTTON_MED_HEIGHT;
	s_ingame.team.color					= CT_DKPURPLE1;
	s_ingame.team.color2				= CT_LTPURPLE1;
	s_ingame.team.textX					= MENU_BUTTON_TEXT_X;
	s_ingame.team.textY					= MENU_BUTTON_TEXT_Y;
	s_ingame.team.textEnum				= MBT_TEAMCLASS;
	s_ingame.team.textcolor				= CT_BLACK;
	s_ingame.team.textcolor2			= CT_WHITE;


	y += INGAME_MENU_VERTICAL_SPACING;
	s_ingame.addbots.generic.type		= MTYPE_BITMAP;
	s_ingame.addbots.generic.flags		= QMF_HIGHLIGHT_IF_FOCUS;
	s_ingame.addbots.generic.x			= x;
	s_ingame.addbots.generic.y			= y;
	s_ingame.addbots.generic.id			= ID_ADDBOTS;
	s_ingame.addbots.generic.name		= BUTTON_GRAPHIC_LONGRIGHT;
	s_ingame.addbots.generic.callback	= InGame_Event; 
	s_ingame.addbots.width				= MENU_BUTTON_MED_WIDTH;
	s_ingame.addbots.height				= MENU_BUTTON_MED_HEIGHT;
	s_ingame.addbots.color				= CT_DKPURPLE1;
	s_ingame.addbots.color2				= CT_LTPURPLE1;
	s_ingame.addbots.textX				= MENU_BUTTON_TEXT_X;
	s_ingame.addbots.textY				= MENU_BUTTON_TEXT_Y;
	s_ingame.addbots.textEnum			= MBT_INGAMEADDSIMULANTS;
	s_ingame.addbots.textcolor			= CT_BLACK;
	s_ingame.addbots.textcolor2			= CT_WHITE;
	if( !trap_Cvar_VariableValue( "sv_running" ) || !trap_Cvar_VariableValue( "bot_enable" ) || (trap_Cvar_VariableValue( "g_gametype" ) == GT_SINGLE_PLAYER)) 
	{
		s_ingame.addbots.generic.flags |= QMF_GRAYED;
	}

	y += INGAME_MENU_VERTICAL_SPACING;
	s_ingame.removebots.generic.type		= MTYPE_BITMAP;
	s_ingame.removebots.generic.flags		= QMF_HIGHLIGHT_IF_FOCUS;
	s_ingame.removebots.generic.x			= x;
	s_ingame.removebots.generic.y			= y;
	s_ingame.removebots.generic.id			= ID_REMOVEBOTS;
	s_ingame.removebots.generic.name		= BUTTON_GRAPHIC_LONGRIGHT;
	s_ingame.removebots.generic.callback	= InGame_Event; 
	s_ingame.removebots.width				= MENU_BUTTON_MED_WIDTH;
	s_ingame.removebots.height				= MENU_BUTTON_MED_HEIGHT;
	s_ingame.removebots.color				= CT_DKPURPLE1;
	s_ingame.removebots.color2				= CT_LTPURPLE1;
	s_ingame.removebots.textX				= MENU_BUTTON_TEXT_X;
	s_ingame.removebots.textY				= MENU_BUTTON_TEXT_Y;
	s_ingame.removebots.textEnum			= MBT_INGAMEREMOVESIMULANTS;
	s_ingame.removebots.textcolor			= CT_BLACK;
	s_ingame.removebots.textcolor2			= CT_WHITE;
	if( !trap_Cvar_VariableValue( "sv_running" ) || !trap_Cvar_VariableValue( "bot_enable" ) || (trap_Cvar_VariableValue( "g_gametype" ) == GT_SINGLE_PLAYER)) {
		s_ingame.removebots.generic.flags |= QMF_GRAYED;
	}

	y += INGAME_MENU_VERTICAL_SPACING;
	s_ingame.teamorders.generic.type		= MTYPE_BITMAP;
	s_ingame.teamorders.generic.flags		= QMF_HIGHLIGHT_IF_FOCUS;
	s_ingame.teamorders.generic.x			= x;
	s_ingame.teamorders.generic.y			= y;
	s_ingame.teamorders.generic.id			= ID_TEAMORDERS;
	s_ingame.teamorders.generic.name		= BUTTON_GRAPHIC_LONGRIGHT;
	s_ingame.teamorders.generic.callback	= InGame_Event; 
	s_ingame.teamorders.width				= MENU_BUTTON_MED_WIDTH;
	s_ingame.teamorders.height				= MENU_BUTTON_MED_HEIGHT;
	s_ingame.teamorders.color				= CT_DKPURPLE1;
	s_ingame.teamorders.color2				= CT_LTPURPLE1;
	s_ingame.teamorders.textX				= MENU_BUTTON_TEXT_X;
	s_ingame.teamorders.textY				= MENU_BUTTON_TEXT_Y;
	s_ingame.teamorders.textEnum			= MBT_INGAMETEAMORDERS;
	s_ingame.teamorders.textcolor			= CT_BLACK;
	s_ingame.teamorders.textcolor2			= CT_WHITE;


	y += INGAME_MENU_VERTICAL_SPACING;
	s_ingame.buymenu.generic.type			= MTYPE_BITMAP;
	s_ingame.buymenu.generic.flags			= QMF_HIGHLIGHT_IF_FOCUS;
	s_ingame.buymenu.generic.x				= x;
	s_ingame.buymenu.generic.y				= y;
	s_ingame.buymenu.generic.id				= ID_BUYMENU;
	s_ingame.buymenu.generic.name			= BUTTON_GRAPHIC_LONGRIGHT;
	s_ingame.buymenu.generic.callback		= InGame_Event; 
	s_ingame.buymenu.width					= MENU_BUTTON_MED_WIDTH;
	s_ingame.buymenu.height					= MENU_BUTTON_MED_HEIGHT;
	s_ingame.buymenu.color					= CT_DKPURPLE1;
	s_ingame.buymenu.color2					= CT_LTPURPLE1;
	s_ingame.buymenu.textX					= MENU_BUTTON_TEXT_X;
	s_ingame.buymenu.textY					= MENU_BUTTON_TEXT_Y;
	s_ingame.buymenu.textEnum				= MBT_INGAMETEAMORDERS;
	s_ingame.buymenu.textcolor				= CT_BLACK;
	s_ingame.buymenu.textcolor2				= CT_WHITE;

	// make sure it's a team game
	trap_GetConfigString( CS_SERVERINFO, info, sizeof(info) );
	if( (atoi( Info_ValueForKey( info, "g_gametype" ) )) < GT_TEAM)
	{
		s_ingame.teamorders.generic.flags |= QMF_GRAYED;
	}
	else 
	{
		trap_GetClientState( &cs );
		trap_GetConfigString( CS_PLAYERS + cs.clientNum, info, MAX_INFO_STRING );
		team = atoi( Info_ValueForKey( info, "t" ) );
		if( team == TEAM_SPECTATOR ) 
		{
			s_ingame.teamorders.generic.flags |= QMF_GRAYED;
		}
	}
	x = 152;
	y = 68;
	s_ingame.setup.generic.type			= MTYPE_BITMAP;
	s_ingame.setup.generic.flags		= QMF_HIGHLIGHT_IF_FOCUS;
	s_ingame.setup.generic.x			= x;
	s_ingame.setup.generic.y			= y;
	s_ingame.setup.generic.id			= ID_SETUP;
	s_ingame.setup.generic.name			= BUTTON_GRAPHIC_LONGRIGHT;
	s_ingame.setup.generic.callback		= InGame_Event; 
	s_ingame.setup.width				= MENU_BUTTON_MED_WIDTH;
	s_ingame.setup.height				= MENU_BUTTON_MED_HEIGHT;
	s_ingame.setup.color				= CT_DKPURPLE1;
	s_ingame.setup.color2				= CT_LTPURPLE1;
	s_ingame.setup.textX				= MENU_BUTTON_TEXT_X;
	s_ingame.setup.textY				= MENU_BUTTON_TEXT_Y;
	s_ingame.setup.textEnum				= MBT_INGAMESETUP;
	s_ingame.setup.textcolor			= CT_BLACK;
	s_ingame.setup.textcolor2			= CT_WHITE;

	y += INGAME_MENU_VERTICAL_SPACING;
	s_ingame.server.generic.type		= MTYPE_BITMAP;
	s_ingame.server.generic.flags		= QMF_HIGHLIGHT_IF_FOCUS;
	s_ingame.server.generic.x			= x;
	s_ingame.server.generic.y			= y;
	s_ingame.server.generic.id			= ID_SERVERINFO;
	s_ingame.server.generic.name		= BUTTON_GRAPHIC_LONGRIGHT;
	s_ingame.server.generic.callback	= InGame_Event; 
	s_ingame.server.width				= MENU_BUTTON_MED_WIDTH;
	s_ingame.server.height				= MENU_BUTTON_MED_HEIGHT;
	s_ingame.server.color				= CT_DKPURPLE1;
	s_ingame.server.color2				= CT_LTPURPLE1;
	s_ingame.server.textX				= MENU_BUTTON_TEXT_X;
	s_ingame.server.textY				= MENU_BUTTON_TEXT_Y;
	s_ingame.server.textEnum			= MBT_INGAMESERVERDATA;
	s_ingame.server.textcolor			= CT_BLACK;
	s_ingame.server.textcolor2			= CT_WHITE;

	y = 365;

	s_ingame.leave.generic.type				= MTYPE_BITMAP;
	s_ingame.leave.generic.flags			= QMF_HIGHLIGHT_IF_FOCUS;
	s_ingame.leave.generic.x				= 126;
	s_ingame.leave.generic.y				= y;
	s_ingame.leave.generic.id				= ID_LEAVEARENA;
	s_ingame.leave.generic.name				= BUTTON_GRAPHIC_LONGRIGHT;
	s_ingame.leave.generic.callback			= InGame_Event; 
	s_ingame.leave.width					= MENU_BUTTON_MED_WIDTH;
	s_ingame.leave.height					= MENU_BUTTON_MED_HEIGHT + 6;
	s_ingame.leave.color					= CT_DKPURPLE1;
	s_ingame.leave.color2					= CT_LTPURPLE1;
	s_ingame.leave.textX					= MENU_BUTTON_TEXT_X;
	s_ingame.leave.textY					= MENU_BUTTON_TEXT_Y;
	s_ingame.leave.textEnum					= MBT_INGAMELEAVE;
	s_ingame.leave.textcolor				= CT_BLACK;
	s_ingame.leave.textcolor2				= CT_WHITE;

	s_ingame.restart.generic.type		= MTYPE_BITMAP;
	s_ingame.restart.generic.flags		= QMF_HIGHLIGHT_IF_FOCUS;
	s_ingame.restart.generic.x			= 305;
	s_ingame.restart.generic.y			= y;
	s_ingame.restart.generic.id			= ID_RESTART;
	s_ingame.restart.generic.name		= BUTTON_GRAPHIC_LONGRIGHT;
	s_ingame.restart.generic.callback	= InGame_Event; 
	s_ingame.restart.width				= MENU_BUTTON_MED_WIDTH;
	s_ingame.restart.height				= MENU_BUTTON_MED_HEIGHT + 6;
	s_ingame.restart.color				= CT_DKPURPLE1;
	s_ingame.restart.color2				= CT_LTPURPLE1;
	s_ingame.restart.textX				= MENU_BUTTON_TEXT_X;
	s_ingame.restart.textY				= MENU_BUTTON_TEXT_Y;
	s_ingame.restart.textEnum			= MBT_INGAMERESTART;
	s_ingame.restart.textcolor			= CT_BLACK;
	s_ingame.restart.textcolor2			= CT_WHITE;
	if( !trap_Cvar_VariableValue( "sv_running" ) ) 
	{
		s_ingame.restart.generic.flags |= QMF_GRAYED;
	}

	s_ingame.resume.generic.type			= MTYPE_BITMAP;
	s_ingame.resume.generic.flags			= QMF_HIGHLIGHT_IF_FOCUS;
	s_ingame.resume.generic.x				= 480;
	s_ingame.resume.generic.y				= y;
	s_ingame.resume.generic.id				= ID_RESUME;
	s_ingame.resume.generic.name			= BUTTON_GRAPHIC_LONGRIGHT;
	s_ingame.resume.generic.callback		= InGame_Event; 
	s_ingame.resume.width					= MENU_BUTTON_MED_WIDTH;
	s_ingame.resume.height					= MENU_BUTTON_MED_HEIGHT + 6;
	s_ingame.resume.color					= CT_DKPURPLE1;
	s_ingame.resume.color2					= CT_LTPURPLE1;
	s_ingame.resume.textX					= MENU_BUTTON_TEXT_X;
	s_ingame.resume.textY					= MENU_BUTTON_TEXT_Y;
	s_ingame.resume.textEnum				= MBT_INGAMERESUME;
	s_ingame.resume.textcolor				= CT_BLACK;
	s_ingame.resume.textcolor2				= CT_WHITE;

	s_ingame.screenshot.generic.type				= MTYPE_BITMAP;      
	s_ingame.screenshot.generic.flags				= QMF_HIGHLIGHT_IF_FOCUS;
	s_ingame.screenshot.generic.x					= 477;
	s_ingame.screenshot.generic.y					= 82;
	s_ingame.screenshot.generic.name				= GRAPHIC_SQUARE;
	s_ingame.screenshot.generic.id					= ID_SCREENSHOT;
	s_ingame.screenshot.generic.callback			= InGame_Event; 
	s_ingame.screenshot.width						= MENU_BUTTON_MED_WIDTH;
	s_ingame.screenshot.height						= 36;
	s_ingame.screenshot.color						= CT_DKPURPLE1;
	s_ingame.screenshot.color2						= CT_LTPURPLE1;
	s_ingame.screenshot.textX						= MENU_BUTTON_TEXT_X;
	s_ingame.screenshot.textY						= MENU_BUTTON_TEXT_Y;
	s_ingame.screenshot.textEnum					= MBT_SCREENSHOT;
	s_ingame.screenshot.textcolor					= CT_BLACK;
	s_ingame.screenshot.textcolor2					= CT_WHITE;


	Menu_AddItem( &s_ingame.menu, &s_ingame.team );
	Menu_AddItem( &s_ingame.menu, &s_ingame.addbots );
	Menu_AddItem( &s_ingame.menu, &s_ingame.removebots );
	Menu_AddItem( &s_ingame.menu, &s_ingame.teamorders );
	Menu_AddItem( &s_ingame.menu, &s_ingame.buymenu );
	Menu_AddItem( &s_ingame.menu, &s_ingame.setup );
	Menu_AddItem( &s_ingame.menu, &s_ingame.server );
	Menu_AddItem( &s_ingame.menu, &s_ingame.leave );
	Menu_AddItem( &s_ingame.menu, &s_ingame.restart );
	Menu_AddItem( &s_ingame.menu, &s_ingame.resume );
//	Menu_AddItem( &s_ingame.menu, &s_ingame.quit );
	Menu_AddItem( &s_ingame.menu, &s_ingame.screenshot );
}

/*
=================
InGameQuit_Cache
=================
*/
void InGame_Cache( void ) 
{

}

/*
=================
UI_InGameMenu
=================
*/
void UI_InGameMenu( void ) 
{
	// force as top level menu
	uis.menusp = 0;  

	// set menu cursor to a nice location
	uis.cursorx = 319;
	uis.cursory = 80;

	ingameFlag = qtrue;	// true when ingame menu is in use
	Mouse_Show();

	InGame_MenuInit();
	UI_PushMenu( &s_ingame.menu );
}



/*
=================
InGameQuitMenu_Event
=================
*/
void InGameQuitMenu_Event( void *ptr, int notification ) 
{
	if( notification != QM_ACTIVATED ) 
	{
		return;
	}

	switch( ((menucommon_s*)ptr)->id ) 
	{
	case ID_INGAME_QUIT_NO:
	case ID_INGAMEMENU:
		UI_PopMenu();
		return;
	case ID_INGAME_QUIT_YES:
		UI_PopMenu();
		UI_QuitMenu();
		return;
	}
}

/*
=================
UI_InGameQuitMenu_Draw
=================
*/
static void UI_InGameQuitMenu_Draw( void ) 
{
	UI_MenuFrame(&s_ingamequit.menu);

	// Rounded button that takes place of INGAME MENU button
	trap_R_SetColor( colorTable[CT_LTBROWN1]);
	UI_DrawHandlePic( 482, 136,  MENU_BUTTON_MED_WIDTH - 22, MENU_BUTTON_MED_HEIGHT, uis.whiteShader);
	UI_DrawHandlePic( 460 + MENU_BUTTON_MED_WIDTH -6 , 136,  -19,  MENU_BUTTON_MED_HEIGHT, uis.graphicButtonLeftEnd);	//right

	trap_R_SetColor( colorTable[CT_LTBROWN1]);
	UI_DrawHandlePic(30,203,  47, 186, uis.whiteShader);	// Long left column square on bottom 3rd

	// standard menu drawing
	Menu_Draw( &s_ingamequit.menu );

}

/*
=================
InGameQuitMenu_Init
=================
*/
void InGameQuitMenu_Init( void ) 
{

	memset( &s_ingame, 0 ,sizeof(ingamemenu_t) );

	InGame_Cache();

	s_ingamequit.menu.wrapAround				= qtrue;
	s_ingamequit.menu.fullscreen				= qtrue;
	s_ingamequit.menu.descX						= MENU_DESC_X;
	s_ingamequit.menu.descY						= MENU_DESC_Y;
	s_ingamequit.menu.draw						= UI_InGameQuitMenu_Draw;
	s_ingamequit.menu.titleX					= MENU_TITLE_X;
	s_ingamequit.menu.titleY					= MENU_TITLE_Y;
	s_ingamequit.menu.titleI					= MNT_INGAMEMAIN_TITLE;
	s_ingamequit.menu.footNoteEnum				= MNT_INGAME_MENU;

	s_ingamequit.ingamemenu.generic.type		= MTYPE_BITMAP;
	s_ingamequit.ingamemenu.generic.flags		= QMF_HIGHLIGHT_IF_FOCUS;
	s_ingamequit.ingamemenu.generic.x			= 482;
	s_ingamequit.ingamemenu.generic.y			= 136;
	s_ingamequit.ingamemenu.generic.id			= ID_INGAMEMENU;
	s_ingamequit.ingamemenu.generic.name		= GRAPHIC_SQUARE;
	s_ingamequit.ingamemenu.generic.callback	= InGameQuitMenu_Event; 
	s_ingamequit.ingamemenu.width				= MENU_BUTTON_MED_WIDTH;
	s_ingamequit.ingamemenu.height				= MENU_BUTTON_MED_HEIGHT;
	s_ingamequit.ingamemenu.color				= CT_DKPURPLE1;
	s_ingamequit.ingamemenu.color2				= CT_LTPURPLE1;
	s_ingamequit.ingamemenu.textX				= MENU_BUTTON_TEXT_X;
	s_ingamequit.ingamemenu.textY				= MENU_BUTTON_TEXT_Y;
	s_ingamequit.ingamemenu.textEnum			= MBT_INGAMEMENU;
	s_ingamequit.ingamemenu.textcolor			= CT_BLACK;
	s_ingamequit.ingamemenu.textcolor2			= CT_WHITE;

	s_ingamequit.no.generic.type				= MTYPE_BITMAP;
	s_ingamequit.no.generic.flags				= QMF_HIGHLIGHT_IF_FOCUS;
	s_ingamequit.no.generic.x					= 100;
	s_ingamequit.no.generic.y					= 180;
	s_ingamequit.no.generic.id					= ID_INGAME_QUIT_NO;
	s_ingamequit.no.generic.name				= GRAPHIC_SQUARE;
	s_ingamequit.no.generic.callback			= InGameQuitMenu_Event; 
	s_ingamequit.no.width						= MENU_BUTTON_MED_WIDTH;
	s_ingamequit.no.height						= MENU_BUTTON_MED_HEIGHT;
	s_ingamequit.no.color						= CT_DKPURPLE1;
	s_ingamequit.no.color2						= CT_LTPURPLE1;
	s_ingamequit.no.textX						= MENU_BUTTON_TEXT_X;
	s_ingamequit.no.textY						= MENU_BUTTON_TEXT_Y;
	s_ingamequit.no.textEnum					= MBT_QUIT_NO;
	s_ingamequit.no.textcolor					= CT_BLACK;
	s_ingamequit.no.textcolor2					= CT_WHITE;	

	s_ingamequit.yes.generic.type				= MTYPE_BITMAP;
	s_ingamequit.yes.generic.flags				= QMF_HIGHLIGHT_IF_FOCUS;
	s_ingamequit.yes.generic.x					= 100;
	s_ingamequit.yes.generic.y					= 180;
	s_ingamequit.yes.generic.id					= ID_INGAME_QUIT_YES;
	s_ingamequit.yes.generic.name				= GRAPHIC_SQUARE;
	s_ingamequit.yes.generic.callback			= InGameQuitMenu_Event; 
	s_ingamequit.yes.width						= MENU_BUTTON_MED_WIDTH;
	s_ingamequit.yes.height						= MENU_BUTTON_MED_HEIGHT;
	s_ingamequit.yes.color						= CT_DKPURPLE1;
	s_ingamequit.yes.color2						= CT_LTPURPLE1;
	s_ingamequit.yes.textX						= MENU_BUTTON_TEXT_X;
	s_ingamequit.yes.textY						= MENU_BUTTON_TEXT_Y;
	s_ingamequit.yes.textEnum					= MBT_QUIT_YES;
	s_ingamequit.yes.textcolor					= CT_BLACK;
	s_ingamequit.yes.textcolor2					= CT_WHITE;

	Menu_AddItem( &s_ingamequit.menu, &s_ingamequit.ingamemenu );
	Menu_AddItem( &s_ingamequit.menu, &s_ingamequit.no );
	Menu_AddItem( &s_ingamequit.menu, &s_ingamequit.yes );
}

/*
=================
UI_InGameQuitMenu
=================
*/
void UI_InGameQuitMenu( void ) 
{
	InGameQuitMenu_Init();

	UI_PushMenu( &s_ingamequit.menu );
}

/*
===========================

INGAME DYNAMIC COMMAND MENU

===========================
*/


#define MAX_DYNAMICDEPTH 	6
#define MAX_MENUSTRING 		16

#define MENUSPACE_X		4
#define MENUSPACE_Y		1


typedef void (*createHandler)(void);
typedef void (*eventHandler)(int index);


typedef struct {
	char text[MAX_MENUSTRING];
	int index;
	int id;
	createHandler createSubMenu;
	eventHandler runEvent;
} dynamicitem_t;


typedef struct {
	menuframework_s menu;

	menutext_s item[MAX_MENUITEMS];
	dynamicitem_t data[MAX_MENUITEMS];

	int start[MAX_DYNAMICDEPTH];
	int end[MAX_DYNAMICDEPTH];	// indicates to (last item + 1)
	int active[MAX_DYNAMICDEPTH];

	int gametype;
	int depth;
} dynamicmenu_t;

static dynamicmenu_t s_dynamic;

/*
=================
DynamicMenu_InitSubMenu
=================
*/
static qboolean DynamicMenu_SubMenuInit( void)
{
	int pos;

	if (s_dynamic.depth == MAX_DYNAMICDEPTH)
		return qfalse;

	if (s_dynamic.depth == 0)
		pos = 0;
	else
		pos = s_dynamic.end[s_dynamic.depth - 1];

	if (pos == MAX_MENUITEMS)
		return qfalse;

	s_dynamic.depth++;
	s_dynamic.active[s_dynamic.depth - 1] = -1;
	s_dynamic.start[s_dynamic.depth - 1] = pos;
	s_dynamic.end[s_dynamic.depth - 1] = pos;

	return qtrue;
}

/*
=================
DynamicMenu_AddItem
=================
*/
static qboolean DynamicMenu_AddItem( const char* string, 
	int id, createHandler crh, eventHandler evh)
{
	int index, depth;

	depth = s_dynamic.depth - 1;
	index = s_dynamic.end[depth];

	if (index == MAX_MENUITEMS)
		return qfalse;

	// can't have submenu and event attached to menu item	
	if (crh && evh)
		return qfalse;

	if (!string || !string[0])
		string = "[no text]";

	s_dynamic.data[index].index = index;
	s_dynamic.data[index].id = id;
	s_dynamic.data[index].createSubMenu = crh;
	s_dynamic.data[index].runEvent = evh;
	Q_strncpyz(s_dynamic.data[index].text, string, MAX_MENUSTRING);

	s_dynamic.end[depth]++;

	return qtrue;
}

/*
=================
DynamicMenu_FinishInitSubMenu
=================
*/
static void DynamicMenu_FinishSubMenuInit( void )
{
	int depth;
	int width, maxwidth;
	int height, lineheight;
	int posx, posy;
	int i, count, start, active;
	float scale;
	menutext_s* ptr;
	qboolean submenu;

	depth = s_dynamic.depth - 1;

	// find the widest item
	submenu = qfalse;
	maxwidth = 0;
	start = s_dynamic.start[depth];
	count = s_dynamic.end[depth] - start;
	for ( i = 0; i < count; i++)
	{
		width = 128;
		if (width > maxwidth)
			maxwidth = width;

		if (s_dynamic.data[i + start].createSubMenu)
			submenu = qtrue;	
	}

	scale = UI_ProportionalSizeScale(UI_SMALLFONT);
	if (submenu)
	{
		// space and submenu pointer
		maxwidth += 16;
	}

	maxwidth *= scale;

	// determine the position of the menu
	lineheight = PROP_HEIGHT * scale + 2*MENUSPACE_Y;
	height = count * lineheight;

	if (depth == 0)
	{
		posy = 240 - height/2;
		posx = 0;
	}
	else
	{
		active = s_dynamic.active[depth - 1];
		posx = s_dynamic.item[active].generic.right;
		posy = s_dynamic.item[active].generic.top;

		if (posy + height > 480 - 64)
			posy = 480 - 64 - height;
	}

	for (i = 0; i < count; i++)
	{
		ptr = &s_dynamic.item[start + i];

		ptr->generic.x = posx + MENUSPACE_X;
		ptr->generic.y = posy + i*lineheight + MENUSPACE_Y;

		ptr->generic.left = posx;
		ptr->generic.right = posx + maxwidth + 2*MENUSPACE_X;
		ptr->generic.top = posy + i*lineheight;
		ptr->generic.bottom = posy + (i+1)*lineheight - 1;

		ptr->generic.flags &= ~(QMF_HIDDEN|QMF_INACTIVE);
	}
}

/*
=================
DynamicMenu_OnActiveList
=================
*/
static qboolean DynamicMenu_OnActiveList( int index )
{
	int depth;
	int i;

	depth = s_dynamic.depth;

	for ( i = 0; i < depth ; i++)
		if (s_dynamic.active[i] == index)
			return qtrue;
			
	return qfalse;
}




/*
=================
DynamicMenu_MenuItemDraw
=================
*/
static void DynamicMenu_MenuItemDraw( void* self )
{
	int		x;
	int		y;

	int		w,h;
	float *	color;
	int		style;
	menutext_s* t;
	vec4_t	back_color;

	t = (menutext_s*)self;


	// draw the background;
	x = t->generic.left;
	y = t->generic.top;
	w = t->generic.right - x;
	h = t->generic.bottom - y;

	back_color[0] = 1.0;
	back_color[1] = 1.0;
	back_color[2] = 1.0;
	if (DynamicMenu_OnActiveList(t->generic.id))
	{
		back_color[3] = 0.33;
	}
	else
	{
		back_color[3] = 0.1;
	}

	UI_FillRect(x, y, w, h, back_color);

	// draw the text
	x = t->generic.x;
	y = t->generic.y;

	if (t->generic.flags & QMF_GRAYED)
		color = text_color_disabled;
	else
		color = t->color;

	style = t->style;
	if( t->generic.flags & QMF_PULSEIFFOCUS ) {
		if( Menu_ItemAtCursor( t->generic.parent ) == t ) {
			style |= UI_PULSE;
		}
		else {
			style |= UI_INVERSE;
		}
	}

	UI_DrawProportionalString( x, y, t->string, style, color );

	// draw the cursor for submenu if needed
	x = t->generic.left + w;
	if (s_dynamic.data[ t->generic.id ].createSubMenu)
	{
		UI_DrawChar( x, y, 13, style|UI_RIGHT, color);
	}
}




/*
=================
DynamicMenu_MenuDraw
=================
*/
static void DynamicMenu_MenuDraw( void )
{
//	UI_DrawString(0, 0, va("depth:%i", s_dynamic.depth), 
//		UI_SMALLFONT, color_white);
//	UI_DrawString(0, 32, va("active: %i %i %i", 
//		s_dynamic.active[0], s_dynamic.active[1], s_dynamic.active[2] ),
//		UI_SMALLFONT, color_white);

	Menu_Draw(&s_dynamic.menu);
}

/*
=================
DynamicMenu_IndexDepth
=================
*/
static int DynamicMenu_IndexDepth( int pos )
{
	int i;
	int maxdepth, depth;

	maxdepth = s_dynamic.depth;
	depth = 0;
	for (i = 0; i < maxdepth; i++)
	{
		if (pos < s_dynamic.end[i])
		{
			depth = i + 1;
			break;
		}
	}

	return depth;
}



/*
=================
DynamicMenu_SetFocus
=================
*/
static void DynamicMenu_SetFocus( int pos )
{
	int i;
	int depth, newdepth;

	depth = s_dynamic.depth;
	newdepth = DynamicMenu_IndexDepth(pos);

	if (newdepth == 0)
	{
		Com_Printf("SetFocus: index %i outside menu\n", pos);
		return;
	}

	s_dynamic.active[ newdepth - 1 ] = pos;
	s_dynamic.depth = newdepth;

	// hide any previous submenus
	if (newdepth < depth)
	{
		for (i = s_dynamic.start[ newdepth ]; 
			i < s_dynamic.end[depth - 1]; i++)
		{
			s_dynamic.item[i].generic.flags |= (QMF_HIDDEN|QMF_INACTIVE);
			s_dynamic.item[i].generic.flags &= ~QMF_GRAYED;
		}
	}

	s_dynamic.active[newdepth - 1] = pos;

	// show this sub-menu (if needed)
	if (s_dynamic.data[pos].createSubMenu)
		s_dynamic.data[pos].createSubMenu();
}


/*
=================
DynamicMenu_ClearFocus
=================
*/
static void DynamicMenu_ClearFocus( int pos )
{
}



/*
=================
DynamicMenu_ActivateControl
=================
*/
static void DynamicMenu_ActivateControl( int pos )
{
	int i;
	int depth;

	depth = DynamicMenu_IndexDepth(pos);

	if (depth == 0)
	{
		Com_Printf("ActivateControl: index %i outside menu\n", pos);
		return;
	}

	// not at the deepest level, can't be a command
	if (depth < s_dynamic.depth)
		return;

	if (s_dynamic.data[pos].runEvent)
		s_dynamic.data[pos].runEvent(pos);
	else
		Com_Printf("ActivateControl: index %i has no event\n", pos);
}




/*
=================
DynamicMenu_MenuEvent
=================
*/
static void DynamicMenu_MenuEvent( void* self, int event )
{
	menutext_s* t;

	t = (menutext_s*)self;

	switch (event)
	{
	case QM_GOTFOCUS:
		DynamicMenu_SetFocus(t->generic.id);
		break;
	case QM_LOSTFOCUS:
		DynamicMenu_ClearFocus(t->generic.id);
		break;
	case QM_ACTIVATED:
		DynamicMenu_ActivateControl(t->generic.id);
		break;
	}
}





/*
=================
DynamicMenu_Close
=================
*/
static void DynamicMenu_Close( void )
{
	UI_PopMenu();
}

enum {
	COM_AMMO,
	COM_DEFUSER,
	COM_ARMOR,
	COM_HARMOR
} commandId;

enum {
	BC_IMOD,
	BC_SCAVENGER,
	BC_STASIS,
	BC_GRENADE,
	BC_TETRION,
	BC_PHOTON,
	BC_ARC
} botCommandId;


/*
=================
DM_Buy_Event
=================
*/
static void DM_Buy_Event( int index )
{

	int cmd;

	cmd = s_dynamic.data[index].id;
	switch (cmd) {
	case BC_IMOD:
		{
			trap_Cmd_ExecuteText( EXEC_NOW, "give imod\n");
			break;
		}
	case BC_SCAVENGER:
		{
			trap_Cmd_ExecuteText( EXEC_NOW, "give scavenger\n");
			break;
		}
	case BC_STASIS:
		{
			trap_Cmd_ExecuteText( EXEC_NOW, "give stasis\n");
			break;
		}
	case BC_GRENADE:
		{
			trap_Cmd_ExecuteText( EXEC_NOW, "give grenade\n");
			break;
		}
	case BC_TETRION:
		{
			trap_Cmd_ExecuteText( EXEC_NOW, "give tetrion\n");
			break;
		}
	case BC_PHOTON:
		{
			trap_Cmd_ExecuteText( EXEC_NOW, "give photon\n");
			break;
		}
	case BC_ARC:
		{
			trap_Cmd_ExecuteText( EXEC_NOW, "give arc\n");
			break;
		}
	};

}

/*
=================
DM_Buy_SubMenu
=================
*/
static void DM_Buy_SubMenu( void )
{
	DynamicMenu_SubMenuInit();

	DynamicMenu_AddItem("I-Mod - 1", BC_IMOD, NULL, DM_Buy_Event);
	DynamicMenu_AddItem("Scavenger - 2", BC_SCAVENGER, NULL, DM_Buy_Event);
	DynamicMenu_AddItem("Stasis - 3", BC_STASIS, NULL, DM_Buy_Event);
	DynamicMenu_AddItem("G Launcher - 4", BC_GRENADE, NULL, DM_Buy_Event);
	DynamicMenu_AddItem("T Disrupter - 5", BC_TETRION, NULL, DM_Buy_Event);
	DynamicMenu_AddItem("P Burst - 6", BC_PHOTON, NULL, DM_Buy_Event);
	DynamicMenu_AddItem("Arc Welder - 7", BC_ARC, NULL, DM_Buy_Event);

	DynamicMenu_FinishSubMenuInit();
}

/*
=================
DM_Close_Event
=================
*/
static void DM_Close_Event( int index )
{
	UI_PopMenu();
}

/*
=================
DM_BuyB_Event
=================
*/
static void DM_BuyB_Event( int index )
{

	int cmd;

	cmd = s_dynamic.data[index].id;
	switch (cmd) {
	case COM_AMMO:
		{
			trap_Cmd_ExecuteText( EXEC_NOW, "give ammo\n" );
			break;
		}
	case COM_DEFUSER:
		{
			break;
		}
	case COM_ARMOR:
		{
			trap_Cmd_ExecuteText( EXEC_NOW, "give armor\n" );
			break;
		}
	case COM_HARMOR:
		{
			trap_Cmd_ExecuteText( EXEC_NOW, "give harmor\n" );
			break;
		}
	};
}

/*
=================
DynamicMenu_InitPrimaryMenu
=================
*/
static void DynamicMenu_InitPrimaryMenu( void )
{
	DynamicMenu_SubMenuInit();

	DynamicMenu_AddItem("Close Menu", 0, NULL, DM_Close_Event);
	DynamicMenu_AddItem("Buy Weapons", 0, DM_Buy_SubMenu, NULL);
	DynamicMenu_AddItem("Buy Ammo - 1", COM_AMMO, NULL, DM_BuyB_Event);
	DynamicMenu_AddItem("Buy Armor - 1", COM_ARMOR, NULL, DM_BuyB_Event);
	DynamicMenu_AddItem("Buy HArmor - 2", COM_HARMOR, NULL, DM_BuyB_Event);

	DynamicMenu_FinishSubMenuInit();
}

/*
=================
DynamicMenu_MenuInit
=================
*/
static void DynamicMenu_MenuInit( void )
{
	int i;

	s_dynamic.menu.draw = DynamicMenu_MenuDraw;
	s_dynamic.menu.fullscreen = qfalse;
	s_dynamic.menu.wrapAround = qfalse;

	for (i = 0; i < MAX_MENUITEMS; i++)
	{
		s_dynamic.item[i].generic.type = MTYPE_PTEXT;
		s_dynamic.item[i].generic.flags = QMF_INACTIVE
			|QMF_HIDDEN|QMF_NODEFAULTINIT|QMF_PULSEIFFOCUS;
		s_dynamic.item[i].generic.ownerdraw = DynamicMenu_MenuItemDraw ;
		s_dynamic.item[i].generic.callback = DynamicMenu_MenuEvent ;
		s_dynamic.item[i].generic.id = i;
		s_dynamic.item[i].string = s_dynamic.data[i].text;
		s_dynamic.item[i].style = UI_SMALLFONT|UI_DROPSHADOW;
		s_dynamic.item[i].color = color_red;

		Menu_AddItem(&s_dynamic.menu, &s_dynamic.item[i]);
	}

	// start up the menu system
	s_dynamic.depth = 0;

//	Uncomment the next line if adding part II as well
//	DynamicMenu_InitMapItems();

	DynamicMenu_InitPrimaryMenu();
}






/*
=================
UI_DynamicMenuCache
=================
*/
void UI_DynamicMenuCache( void )
{
}




/*
=================
UI_DynamicMenu
=================
*/
void UI_DynamicMenu( void )
{
	uiClientState_t	cs;
	char	info[MAX_INFO_STRING];
	int	playerTeam;

	trap_GetClientState( &cs );
	trap_GetConfigString( CS_PLAYERS 
		+ cs.clientNum, info, MAX_INFO_STRING );
	playerTeam = atoi(Info_ValueForKey(info, "t"));

//	Uncomment the next two code lines if adding part II 
//	as well, or specs can't use the menu either
//	if (playerTeam == TEAM_SPECTATOR)
//		return;

	memset(&s_dynamic.menu, 0, sizeof(dynamicmenu_t));

	s_dynamic.gametype = (int)trap_Cvar_VariableValue("g_gametype");

//	Uncomment the next three lines if adding part II as well
//	if (s_dynamic.gametype != GT_TEAM && 
//			s_dynamic.gametype != GT_CTF)
//		return;

	UI_DynamicMenuCache();

	// force as top level menu
	uis.menusp = 0;

	// set menu cursor to a nice location
	uis.cursorx = 50;
	uis.cursory = 240;

	DynamicMenu_MenuInit();

	UI_PushMenu( &s_dynamic.menu );
}



/*
=================
UI_DynamicCommandMenu_f
=================
*/
void UI_DynamicCommandMenu_f( void )
{
	UI_DynamicMenu();
}

